# Computation View

!!! warning inline end "Experimental"
    The Workbench View classes are currently in experimental mode so have fun but expect issues and API changes going forward.
    
**Note:** This class can be automatically invoked from DataSource/FeatureSet `set_computation_columns()` [DataSource](../artifacts/athena_source.md) or [FeatureSet](../artifacts/feature_set_core.md). If you need more control then you can use this class directly.
    
::: workbench.core.views.computation_view

## Questions?
<img align="right" src="../../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 